[Bf-blender-cvs] [aeae4c2] soc-2014-bge: No changes, commiting because there was a problem with the way I uploaded the revision

Ines Almeida noreply at git.blender.org
Tue Jun 24 16:59:32 CEST 2014


Commit: aeae4c2d9d0b71de3b413224414cf29c79a1fc86
Author: Ines Almeida
Date:   Tue Jun 24 15:44:34 2014 +0100
https://developer.blender.org/rBaeae4c2d9d0b71de3b413224414cf29c79a1fc86

No changes, commiting because there was a problem with the way I uploaded the revision

Summary:

Reviewers:

CC:

===================================================================

M	release/scripts/startup/bl_ui/properties_game.py
M	source/gameengine/Converter/BL_BlenderDataConversion.cpp

===================================================================

diff --git a/release/scripts/startup/bl_ui/properties_game.py b/release/scripts/startup/bl_ui/properties_game.py
index 503b3cd..b04b1b7 100644
--- a/release/scripts/startup/bl_ui/properties_game.py
+++ b/release/scripts/startup/bl_ui/properties_game.py
@@ -226,8 +226,9 @@ class PHYSICS_PT_game_collision_bounds(PhysicsButtonsPanel, Panel):
 
         row = layout.row()
         row.prop(game, "collision_margin", text="Margin", slider=True)
-        row.prop(game, "use_collision_compound", text="Compound")
-
+        sub = row.row()
+        sub.active = game.physics_type != 'SOFT_BODY'
+        sub.prop(game, "use_collision_compound", text="Compound")
 
 class PHYSICS_PT_game_obstacles(PhysicsButtonsPanel, Panel):
     bl_label = "Create Obstacle"
diff --git a/source/gameengine/Converter/BL_BlenderDataConversion.cpp b/source/gameengine/Converter/BL_BlenderDataConversion.cpp
index e511f01..804b698 100644
--- a/source/gameengine/Converter/BL_BlenderDataConversion.cpp
+++ b/source/gameengine/Converter/BL_BlenderDataConversion.cpp
@@ -1389,16 +1389,16 @@ static void BL_CreatePhysicsObjectNew(KX_GameObject* gameobj,
 	}
 
 	bool isCompoundChild = false;
-	bool hasCompoundChildren = !parent && (blenderobject->gameflag & OB_CHILD);
+	bool hasCompoundChildren = !parent && (blenderobject->gameflag & OB_CHILD) && !(blenderobject->gameflag & OB_SOFT_BODY);
 
 	/* When the parent is not OB_DYNAMIC and has no OB_COLLISION then it gets no bullet controller
 	 * and cant be apart of the parents compound shape */
 	if (parent && (parent->gameflag & (OB_DYNAMIC | OB_COLLISION))) {
 		
-		if ((parent->gameflag & OB_CHILD) != 0 && (blenderobject->gameflag & OB_CHILD))
+		if (parent && (parent->gameflag & (OB_DYNAMIC | OB_COLLISION)) && !(parent->gameflag & OB_SOFT_BODY)) {
 		{
 			isCompoundChild = true;
-		} 
+		}
 	}
 	if (processCompoundChildren != isCompoundChild)
 		return;
@@ -1389,16 +1389,16 @@ static void BL_CreatePhysicsObjectNew(KX_GameObject* gameobj,
 
 	/* When the parent is not OB_DYNAMIC and has no OB_COLLISION then it gets no bullet controller
-	 * and cant be apart of the parents compound shape */
+	 * and cant be apart of the parents compound shape, same goes for OB_SOFT_BODY */
 	if (parent && (parent->gameflag & (OB_DYNAMIC | OB_COLLISION))) {
 		




More information about the Bf-blender-cvs mailing list